@@ -11,11 +11,10 @@
 
 """
 import base64
-
-import six
+from typing import Union
 
 
-def b64encode(data):
+def b64encode(data: bytes) -> bytes:
     """JOSE Base64 encode.
 
     :param data: Data to be encoded.
@@ -27,12 +26,12 @@ def b64encode(data):
     :raises TypeError: if ``data`` is of incorrect type
 
     """
-    if not isinstance(data, six.binary_type):
-        raise TypeError('argument should be {0}'.format(six.binary_type))
-    return base64.urlsafe_b64encode(data).rstrip(b'=')
+    if not isinstance(data, bytes):
+        raise TypeError("argument should be bytes")
+    return base64.urlsafe_b64encode(data).rstrip(b"=")
 
 
-def b64decode(data):
+def b64decode(data: Union[bytes, str]) -> bytes:
     """JOSE Base64 decode.
 
     :param data: Base64 string to be decoded. If it's unicode, then
@@ -46,13 +45,12 @@ def b64decode(data):
     :raises ValueError: if input is unicode with non-ASCII characters
 
     """
-    if isinstance(data, six.string_types):
+    if isinstance(data, str):
         try:
-            data = data.encode('ascii')
+            data = data.encode("ascii")
         except UnicodeEncodeError:
-            raise ValueError(
-                'unicode argument should contain only ASCII characters')
-    elif not isinstance(data, six.binary_type):
-        raise TypeError('argument should be a str or unicode')
+            raise ValueError("unicode argument should contain only ASCII characters")
+    elif not isinstance(data, bytes):
+        raise TypeError("argument should be a str or unicode")
 
-    return base64.urlsafe_b64decode(data + b'=' * (4 - (len(data) % 4)))
+    return base64.urlsafe_b64decode(data + b"=" * (4 - (len(data) % 4)))
