@@ -1,13 +1,13 @@
 """JOSE utilities."""
 import abc
-from types import ModuleType
-from typing import Union, Any, Callable, Iterator, Tuple, List, TypeVar, cast
-from collections.abc import Hashable, Mapping
 import sys
 import warnings
+from collections.abc import Hashable, Mapping
+from types import ModuleType
+from typing import Any, Callable, Iterator, List, Tuple, TypeVar, Union, cast
 
-from OpenSSL import crypto
 from cryptography.hazmat.primitives.asymmetric import ec, rsa
+from OpenSSL import crypto
 
 
 # Deprecated. Please use built-in decorators @classmethod and abc.abstractmethod together instead.
@@ -15,7 +15,7 @@ def abstractclassmethod(func: Callable) -> classmethod:
     return classmethod(abc.abstractmethod(func))
 
 
-class ComparableX509:  # pylint: disable=too-few-public-methods
+class ComparableX509:
     """Wrapper for OpenSSL.crypto.X509** objects that supports __eq__.
 
     :ivar wrapped: Wrapped certificate or certificate request.
@@ -24,8 +24,7 @@ class ComparableX509:  # pylint: disable=too-few-public-methods
     """
 
     def __init__(self, wrapped: Union[crypto.X509, crypto.X509Req]) -> None:
-        assert isinstance(wrapped, crypto.X509) or isinstance(
-            wrapped, crypto.X509Req)
+        assert isinstance(wrapped, crypto.X509) or isinstance(wrapped, crypto.X509Req)
         self.wrapped = wrapped
 
     def __getattr__(self, name: str) -> Any:
@@ -52,60 +51,66 @@ class ComparableX509:  # pylint: disable=too-few-public-methods
     def __eq__(self, other: Any) -> bool:
         if not isinstance(other, self.__class__):
             return NotImplemented
-        # pylint: disable=protected-access
         return self._dump() == other._dump()
 
     def __hash__(self) -> int:
         return hash((self.__class__, self._dump()))
 
     def __repr__(self) -> str:
-        return '<{0}({1!r})>'.format(self.__class__.__name__, self.wrapped)
+        return "<{0}({1!r})>".format(self.__class__.__name__, self.wrapped)
 
 
-class ComparableKey:  # pylint: disable=too-few-public-methods
+class ComparableKey:
     """Comparable wrapper for ``cryptography`` keys.
 
     See https://github.com/pyca/cryptography/issues/2122.
 
     """
+
     __hash__: Callable[[], int] = NotImplemented
 
-    def __init__(self,
-                 wrapped: Union[
-                     rsa.RSAPrivateKeyWithSerialization,
-                     rsa.RSAPublicKeyWithSerialization,
-                     ec.EllipticCurvePrivateKeyWithSerialization,
-                     ec.EllipticCurvePublicKeyWithSerialization]):
+    def __init__(
+        self,
+        wrapped: Union[
+            rsa.RSAPrivateKeyWithSerialization,
+            rsa.RSAPublicKeyWithSerialization,
+            ec.EllipticCurvePrivateKeyWithSerialization,
+            ec.EllipticCurvePublicKeyWithSerialization,
+        ],
+    ):
         self._wrapped = wrapped
 
     def __getattr__(self, name: str) -> Any:
         return getattr(self._wrapped, name)
 
     def __eq__(self, other: Any) -> bool:
-        # pylint: disable=protected-access
-        if (not isinstance(other, self.__class__) or
-                self._wrapped.__class__ is not other._wrapped.__class__):
+        if (
+            not isinstance(other, self.__class__)
+            or self._wrapped.__class__ is not other._wrapped.__class__
+        ):
             return NotImplemented
-        elif hasattr(self._wrapped, 'private_numbers'):
+        elif hasattr(self._wrapped, "private_numbers"):
             return self.private_numbers() == other.private_numbers()
-        elif hasattr(self._wrapped, 'public_numbers'):
+        elif hasattr(self._wrapped, "public_numbers"):
             return self.public_numbers() == other.public_numbers()
         else:
             return NotImplemented
 
     def __repr__(self) -> str:
-        return '<{0}({1!r})>'.format(self.__class__.__name__, self._wrapped)
+        return "<{0}({1!r})>".format(self.__class__.__name__, self._wrapped)
 
-    def public_key(self) -> 'ComparableKey':
+    def public_key(self) -> "ComparableKey":
         """Get wrapped public key."""
-        if isinstance(self._wrapped, (rsa.RSAPublicKeyWithSerialization,
-                                      ec.EllipticCurvePublicKeyWithSerialization)):
+        if isinstance(
+            self._wrapped,
+            (rsa.RSAPublicKeyWithSerialization, ec.EllipticCurvePublicKeyWithSerialization),
+        ):
             return self
 
         return self.__class__(self._wrapped.public_key())
 
 
-class ComparableRSAKey(ComparableKey):  # pylint: disable=too-few-public-methods
+class ComparableRSAKey(ComparableKey):
     """Wrapper for ``cryptography`` RSA keys.
 
     Wraps around:
@@ -121,8 +126,9 @@ class ComparableRSAKey(ComparableKey):  # pylint: disable=too-few-public-methods
         if isinstance(self._wrapped, rsa.RSAPrivateKeyWithSerialization):
             priv = self.private_numbers()
             pub = priv.public_numbers
-            return hash((self.__class__, priv.p, priv.q, priv.dmp1,
-                         priv.dmq1, priv.iqmp, pub.n, pub.e))
+            return hash(
+                (self.__class__, priv.p, priv.q, priv.dmp1, priv.dmq1, priv.iqmp, pub.n, pub.e)
+            )
         elif isinstance(self._wrapped, rsa.RSAPublicKeyWithSerialization):
             pub = self.public_numbers()
             return hash((self.__class__, pub.n, pub.e))
@@ -130,8 +136,8 @@ class ComparableRSAKey(ComparableKey):  # pylint: disable=too-few-public-methods
         raise NotImplementedError()
 
 
-class ComparableECKey(ComparableKey):  # pylint: disable=too-few-public-methods
-    """Wrapper for ``cryptography`` RSA keys.
+class ComparableECKey(ComparableKey):
+    """Wrapper for ``cryptography`` EC keys.
     Wraps around:
     - :class:`~cryptography.hazmat.primitives.asymmetric.ec.EllipticCurvePrivateKey`
     - :class:`~cryptography.hazmat.primitives.asymmetric.ec.EllipticCurvePublicKey`
@@ -151,11 +157,10 @@ class ComparableECKey(ComparableKey):  # pylint: disable=too-few-public-methods
         raise NotImplementedError()
 
 
-GenericImmutableMap = TypeVar('GenericImmutableMap', bound='ImmutableMap')
+GenericImmutableMap = TypeVar("GenericImmutableMap", bound="ImmutableMap")
 
 
 class ImmutableMap(Mapping, Hashable):
-    # pylint: disable=too-few-public-methods
     """Immutable key to value mapping with attribute access."""
 
     __slots__: Tuple[str, ...] = ()
@@ -164,16 +169,18 @@ class ImmutableMap(Mapping, Hashable):
     def __init__(self, **kwargs: Any) -> None:
         if set(kwargs) != set(self.__slots__):
             raise TypeError(
-                '__init__() takes exactly the following arguments: {0} '
-                '({1} given)'.format(', '.join(self.__slots__),
-                                     ', '.join(kwargs) if kwargs else 'none'))
+                "__init__() takes exactly the following arguments: {0} "
+                "({1} given)".format(
+                    ", ".join(self.__slots__), ", ".join(kwargs) if kwargs else "none"
+                )
+            )
         for slot in self.__slots__:
             object.__setattr__(self, slot, kwargs.pop(slot))
 
     def update(self: GenericImmutableMap, **kwargs: Any) -> GenericImmutableMap:
         """Return updated map."""
         items: Mapping[str, Any] = {**self, **kwargs}
-        return type(self)(**items)  # pylint: disable=star-args
+        return type(self)(**items)
 
     def __getitem__(self, key: str) -> Any:
         try:
@@ -194,15 +201,16 @@ class ImmutableMap(Mapping, Hashable):
         raise AttributeError("can't set attribute")
 
     def __repr__(self) -> str:
-        return '{0}({1})'.format(self.__class__.__name__, ', '.join(
-            '{0}={1!r}'.format(key, value)
-            for key, value in self.items()))
+        return "{0}({1})".format(
+            self.__class__.__name__,
+            ", ".join("{0}={1!r}".format(key, value) for key, value in self.items()),
+        )
 
 
 class frozendict(Mapping, Hashable):
-    # pylint: disable=invalid-name,too-few-public-methods
     """Frozen dictionary."""
-    __slots__ = ('_items', '_keys')
+
+    __slots__ = ("_items", "_keys")
 
     def __init__(self, *args: Any, **kwargs: Any) -> None:
         items: Mapping
@@ -214,8 +222,8 @@ class frozendict(Mapping, Hashable):
             raise TypeError()
         # TODO: support generators/iterators
 
-        object.__setattr__(self, '_items', items)
-        object.__setattr__(self, '_keys', tuple(sorted(items.keys())))
+        object.__setattr__(self, "_items", items)
+        object.__setattr__(self, "_keys", tuple(sorted(items.keys())))
 
     def __getitem__(self, key: str) -> Any:
         return self._items[key]
@@ -242,8 +250,9 @@ class frozendict(Mapping, Hashable):
         raise AttributeError("can't set attribute")
 
     def __repr__(self) -> str:
-        return 'frozendict({0})'.format(', '.join('{0}={1!r}'.format(
-            key, value) for key, value in self._sorted_items()))
+        return "frozendict({0})".format(
+            ", ".join("{0}={1!r}".format(key, value) for key, value in self._sorted_items())
+        )
 
 
 # This class takes a similar approach to the cryptography project to deprecate attributes
@@ -254,15 +263,19 @@ class _UtilDeprecationModule:
     Internal class delegating to a module, and displaying warnings when attributes
     related to the deprecated "abstractclassmethod" attributes in the josepy.util module.
     """
+
     def __init__(self, module: ModuleType) -> None:
-        self.__dict__['_module'] = module
+        self.__dict__["_module"] = module
 
     def __getattr__(self, attr: str) -> Any:
-        if attr == 'abstractclassmethod':
-            warnings.warn('The abstractclassmethod attribute in josepy.util is deprecated and will '
-                          'be removed soon. Please use the built-in decorators @classmethod and '
-                          '@abc.abstractmethod together instead.',
-                          DeprecationWarning, stacklevel=2)
+        if attr == "abstractclassmethod":
+            warnings.warn(
+                "The abstractclassmethod attribute in josepy.util is deprecated and will "
+                "be removed soon. Please use the built-in decorators @classmethod and "
+                "@abc.abstractmethod together instead.",
+                DeprecationWarning,
+                stacklevel=2,
+            )
         return getattr(self._module, attr)
 
     def __setattr__(self, attr: str, value: Any) -> None:  # pragma: no cover
@@ -272,7 +285,7 @@ class _UtilDeprecationModule:
         delattr(self._module, attr)
 
     def __dir__(self) -> List[str]:  # pragma: no cover
-        return ['_module'] + dir(self._module)
+        return ["_module"] + dir(self._module)
 
 
 # Patching ourselves to warn about deprecation and planned removal of some elements in the module.
